namespace elm { namespace naviframe { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Item::style_get() const
{
   const char * __return_value =  ::elm_obj_naviframe_item_style_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Item::style_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type style) const
{
    ::elm_obj_naviframe_item_style_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(style));
}
inline ::efl::eolian::return_traits<void>::type Item::pop_to() const
{
    ::elm_obj_naviframe_item_pop_to(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<bool>::type Item::title_enabled_get() const
{
   Eina_Bool __return_value =  ::elm_obj_naviframe_item_title_enabled_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Item::title_enabled_set( ::efl::eolian::in_traits<bool>::type enable,  ::efl::eolian::in_traits<bool>::type transition) const
{
    ::elm_obj_naviframe_item_title_enabled_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(enable)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(transition));
}
inline ::efl::eolian::return_traits<void>::type Item::promote() const
{
    ::elm_obj_naviframe_item_promote(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Item::pop_cb_set( ::efl::eolian::in_traits<Elm_Naviframe_Item_Pop_Cb>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::elm_obj_naviframe_item_pop_cb_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Naviframe_Item_Pop_Cb,  ::efl::eolian::in_traits<Elm_Naviframe_Item_Pop_Cb>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
}
} } 
namespace eo_cxx {
namespace elm { namespace naviframe { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Item::style_get() const
{
   const char * __return_value =  ::elm_obj_naviframe_item_style_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Item::style_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type style) const
{
    ::elm_obj_naviframe_item_style_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(style));
}
inline ::efl::eolian::return_traits<void>::type Item::pop_to() const
{
    ::elm_obj_naviframe_item_pop_to(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<bool>::type Item::title_enabled_get() const
{
   Eina_Bool __return_value =  ::elm_obj_naviframe_item_title_enabled_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Item::title_enabled_set( ::efl::eolian::in_traits<bool>::type enable,  ::efl::eolian::in_traits<bool>::type transition) const
{
    ::elm_obj_naviframe_item_title_enabled_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(enable)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(transition));
}
inline ::efl::eolian::return_traits<void>::type Item::promote() const
{
    ::elm_obj_naviframe_item_promote(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Item::pop_cb_set( ::efl::eolian::in_traits<Elm_Naviframe_Item_Pop_Cb>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::elm_obj_naviframe_item_pop_cb_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Naviframe_Item_Pop_Cb,  ::efl::eolian::in_traits<Elm_Naviframe_Item_Pop_Cb>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
}
inline elm::naviframe::Item::operator ::elm::naviframe::Item() const { return *static_cast< ::elm::naviframe::Item const*>(static_cast<void const*>(this)); }
inline elm::naviframe::Item::operator ::elm::naviframe::Item&() { return *static_cast< ::elm::naviframe::Item*>(static_cast<void*>(this)); }
inline elm::naviframe::Item::operator ::elm::naviframe::Item const&() const { return *static_cast< ::elm::naviframe::Item const*>(static_cast<void const*>(this)); }
} } }

